var group__fourier__analysis__blk =
[
    [ "gr::fft::fft_v&lt; T, forward &gt;", "classgr_1_1fft_1_1fft__v.html", [
      [ "sptr", "classgr_1_1fft_1_1fft__v.html#a645dd1069dc5f7ec4de28783fd60e7c4", null ],
      [ "make", "classgr_1_1fft_1_1fft__v.html#a978d0d499b03c753c6f2c781c93e07f8", null ],
      [ "nthreads", "classgr_1_1fft_1_1fft__v.html#afeec441a9c43068d8c153016623e0bf1", null ],
      [ "set_nthreads", "classgr_1_1fft_1_1fft__v.html#a649c2363cef1036b9bc89f8559e95885", null ],
      [ "set_window", "classgr_1_1fft_1_1fft__v.html#a6b080f1cf86c442799f71411ea11409b", null ]
    ] ],
    [ "gr::fft::goertzel_fc", "classgr_1_1fft_1_1goertzel__fc.html", [
      [ "sptr", "classgr_1_1fft_1_1goertzel__fc.html#acdc1d9264a76bd5f46a62bbb9c1c5ad4", null ],
      [ "freq", "classgr_1_1fft_1_1goertzel__fc.html#aeddd275a3a73a797c0e9b5fbd99561c2", null ],
      [ "make", "classgr_1_1fft_1_1goertzel__fc.html#a022d0bdf026c27b202cf6aa8e8681b31", null ],
      [ "rate", "classgr_1_1fft_1_1goertzel__fc.html#a23a7a9dfbecd2aac362a8487729c5121", null ],
      [ "set_freq", "classgr_1_1fft_1_1goertzel__fc.html#a80d458fd91ec73fd006d9f3345096d21", null ],
      [ "set_rate", "classgr_1_1fft_1_1goertzel__fc.html#a101d8004ce4d9fcdc42d51e14d63fd0f", null ]
    ] ]
];